@@ -7,14 +7,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::CharClass::POSIX };
 
-use PPIx::Regexp::Constant qw{ MINIMUM_PERL @CARP_NOT };
-
-our $VERSION = '0.090_02';
-
-sub perl_version_introduced {
-#   my ( $self ) = @_;
-    return MINIMUM_PERL;
-}
+our $VERSION = '0.011';
 
 # Note that these guys are recognized by PPIx::Regexp::CharClass::POSIX,
 # and if one of them becomes supported that is where the change needs to
@@ -25,6 +18,7 @@ sub __PPIX_LEXER__finalize {
     return 1;
 }
 
+
 1;
 
 __END__
@@ -44,8 +38,6 @@ PPIx::Regexp::Token::CharClass::POSIX::Unknown - Represent an unknown or unsuppo
 C<PPIx::Regexp::Token::CharClass::POSIX::Unknown> is a
 L<PPIx::Regexp::Token::CharClass::POSIX|PPIx::Regexp::Token::CharClass::POSIX>.
 
-C<PPIx::Regexp::Token::CharClass::POSIX::Unknown> has no descendants.
-
 =head1 DESCRIPTION
 
 This class represents POSIX character classes which are recognized but
@@ -65,9 +57,7 @@ superclass.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
-L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -75,7 +65,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2023, 2025 by Thomas R. Wyant, III
+Copyright (C) 2010, Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
