@@ -35,15 +35,15 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-use PPIx::Regexp::Constant qw{ $MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
 
 my %greediness = (
-    '?' => $MINIMUM_PERL,
+    '?' => MINIMUM_PERL,
     '+' => '5.010',
 );
 
@@ -63,7 +63,7 @@ sub could_be_greediness {
 
 sub perl_version_introduced {
     my ( $self ) = @_;
-    return $greediness{ $self->content() } || $MINIMUM_PERL;
+    return $greediness{ $self->content() } || MINIMUM_PERL;
 }
 
 sub __PPIX_TOKENIZER__regexp {
