@@ -34,9 +34,9 @@ use warnings;
 use base qw{ PPIx::Regexp::Token::Reference };
 
 use Carp qw{ confess };
-use PPIx::Regexp::Constant qw{ $RE_CAPTURE_NAME };
+use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME };
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -56,7 +56,7 @@ sub __PPIX_TOKEN__recognize {
 	[ qr{ \A \( \? (?: ( [-+]? \d+ )) \) }smx, { is_named => 0 } ],
 	[ qr{ \A \( \? (?: R) \) }smx,
 	    { is_named => 0, capture => '0' } ],
-	[ qr{ \A \( \?  (?: & | P> ) ( $RE_CAPTURE_NAME ) \) }smx,
+	[ qr{ \A \( \?  (?: & | P> ) ( @{[ RE_CAPTURE_NAME ]} ) \) }smxo,
 	    { is_named => 1 } ],
     );
 }
