@@ -6,12 +6,12 @@ use warnings;
 use base qw{ PPIx::Regexp::Support };
 
 use Carp qw{ confess };
-use Params::Util 0.25 qw{ _INSTANCE };
-use PPIx::Regexp::Constant qw{ $TOKEN_LITERAL $TOKEN_UNKNOWN };
+use PPIx::Regexp::Constant qw{ TOKEN_LITERAL TOKEN_UNKNOWN };
 use PPIx::Regexp::Token::Assertion		();
 use PPIx::Regexp::Token::Backreference		();
 use PPIx::Regexp::Token::Backtrack		();
 use PPIx::Regexp::Token::CharClass::POSIX	();
+use PPIx::Regexp::Token::CharClass::POSIX::Unknown	();
 use PPIx::Regexp::Token::CharClass::Simple	();
 use PPIx::Regexp::Token::Code			();
 use PPIx::Regexp::Token::Comment		();
@@ -35,10 +35,10 @@ use PPIx::Regexp::Token::Recursion		();
 use PPIx::Regexp::Token::Structure		();
 use PPIx::Regexp::Token::Unknown		();
 use PPIx::Regexp::Token::Whitespace		();
-use Readonly;
+use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 {
     # Names of classes containing tokenization machinery. There are no
@@ -47,7 +47,7 @@ our $VERSION = '0.010';
     # order is in percieved frequency of acceptance, to keep the search
     # as short as possible. If I were conscientious I would gather
     # statistics on this.
-    Readonly::Array my @classes => (
+    my @classes = (	# TODO make readonly when acceptable way appears
 	'PPIx::Regexp::Token::Literal',
 	'PPIx::Regexp::Token::Interpolation',
 	'PPIx::Regexp::Token::Control',			# Note 1
@@ -161,13 +161,13 @@ our $VERSION = '0.010';
 	    mode => 'init',	# Initialize
 	    modifiers => [{}],	# Modifier hash.
 	    pending => [],	# Tokens made but not returned.
-	    prior => $TOKEN_UNKNOWN,	# Prior significant token.
+	    prior => TOKEN_UNKNOWN,	# Prior significant token.
 	    source => $re,	# The object we were initialized with.
 	    trace => __PACKAGE__->_defined_or(
 		$args{trace}, $ENV{PPIX_REGEXP_TOKENIZER_TRACE}, 0 ),
 	};
 
-	if ( _INSTANCE( $re, 'PPI::Element' ) ) {
+	if ( __instance( $re, 'PPI::Element' ) ) {
 	    $self->{content} = $re->content();
 	} elsif ( ref $re ) {
 	    $errstr = ref( $re ) . ' not supported';
@@ -352,7 +352,7 @@ sub make_token {
     "cursor_limit = $self->{cursor_limit}\n";
     my $token = $class->_new( $content ) or return;
     $token->significant() and $self->{expect} = undef;
-    $class eq $TOKEN_UNKNOWN and $self->{failures}++;
+    $class eq TOKEN_UNKNOWN and $self->{failures}++;
 
     $token->__PPIX_TOKEN__post_make( $self, $arg );
 
@@ -522,7 +522,7 @@ sub __PPIX_TOKENIZER__init {
     $tokenizer->{mode} = 'kaput';
     $tokenizer->{content} =~ m/ ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
 	or return $tokenizer->make_token(
-	    length( $tokenizer->{content} ), $TOKEN_UNKNOWN );
+	    length( $tokenizer->{content} ), TOKEN_UNKNOWN );
     my ( $type, $white, $delim ) = ( $1, $2, $3 );
     defined $type or $type = '';
     $tokenizer->{type} = $type;
@@ -605,11 +605,11 @@ sub __PPIX_TOKEN_FALLBACK__regexp {
     if ( $character eq '\\'
 	&& $tokenizer->{cursor_limit} - $tokenizer->{cursor_curr} > 1
     ) {
-	return $tokenizer->make_token( 2, $TOKEN_LITERAL );
+	return $tokenizer->make_token( 2, TOKEN_LITERAL );
     }
 
     # Any normal character is unknown.
-    return $tokenizer->make_token( 1, $TOKEN_UNKNOWN );
+    return $tokenizer->make_token( 1, TOKEN_UNKNOWN );
 }
 
 sub __PPIX_TOKEN_FALLBACK__repl {
@@ -620,13 +620,13 @@ sub __PPIX_TOKEN_FALLBACK__repl {
 	&& defined ( my $next = $tokenizer->peek( 1 ) ) ) {
 
 	if ( $tokenizer->interpolates() || $next eq q<'> || $next eq '\\' ) {
-	    return $tokenizer->make_token( 2, $TOKEN_LITERAL );
+	    return $tokenizer->make_token( 2, TOKEN_LITERAL );
 	}
-	return $tokenizer->make_token( 1, $TOKEN_LITERAL );
+	return $tokenizer->make_token( 1, TOKEN_LITERAL );
     }
 
     # So is any normal character.
-    return $tokenizer->make_token( 1, $TOKEN_LITERAL );
+    return $tokenizer->make_token( 1, TOKEN_LITERAL );
 }
 
 sub __PPIX_TOKENIZER__finish {
